@@ -8,6 +8,7 @@
  * Copyright 2001, Ximian, Inc.
  */
 #include <config.h>
+#include <libgnome/gnome-i18n.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
@@ -50,7 +51,7 @@ html_stream_mem_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);		
 }
 
-HTMLStreamMem *
+static HTMLStreamMem *
 html_stream_mem_construct (HTMLStreamMem *bhtml,
 			   GtkHTMLStream *html_stream)
 {
